@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use UI::Various::core;
 use UI::Various::Input;
@@ -42,7 +42,7 @@ require Exporter;
 our @ISA = qw(UI::Various::Input UI::Various::Curses::base);
 our @EXPORT_OK = qw();
 
-use Curses;
+use Curses::UI;
 
 #########################################################################
 #########################################################################
@@ -145,6 +145,6 @@ under the same terms as Perl itself.  See LICENSE file for more details.
 
 =head1 AUTHOR
 
-Thomas Dorner E<lt>dorner@cpan.orgE<gt>
+Thomas Dorner E<lt>dorner (at) cpan (dot) orgE<gt>
 
 =cut
