@@ -43,7 +43,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use UI::Various::core;
 use UI::Various::widget;
@@ -87,7 +87,7 @@ use constant DEFAULT_ATTRIBUTES => (textvar => dummy_varref());
 Besides the accessors (attributes) described above and by
 L<UI::Various::widget|UI::Various::widget/Attributes> and the methods
 inherited from L<UI::Various::widget|UI::Various::widget/METHODS> only the
-constructor is provided by the abstract C<Input> class itself:
+constructor is provided by the C<Input> class itself:
 
 =cut
 
@@ -128,6 +128,6 @@ under the same terms as Perl itself.  See LICENSE file for more details.
 
 =head1 AUTHOR
 
-Thomas Dorner E<lt>dorner@cpan.orgE<gt>
+Thomas Dorner E<lt>dorner (at) cpan (dot) orgE<gt>
 
 =cut
