@@ -40,7 +40,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use UI::Various::core;
 use UI::Various::toplevel;
@@ -81,7 +81,7 @@ use constant DEFAULT_ATTRIBUTES => (title => '');
 Besides the accessors (attributes) described above and the attributes and
 methods of L<UI::Various::widget>, L<UI::Various::container> and
 L<UI::Various::toplevel>, the following additional methods are provided by
-the abstract C<Window> class itself:
+the C<Window> class itself:
 
 =cut
 
@@ -148,6 +148,6 @@ under the same terms as Perl itself.  See LICENSE file for more details.
 
 =head1 AUTHOR
 
-Thomas Dorner E<lt>dorner@cpan.orgE<gt>
+Thomas Dorner E<lt>dorner (at) cpan (dot) orgE<gt>
 
 =cut
